@@ -7,22 +7,22 @@ import argparse
 import platform
 import requests
 from pathlib import Path
-from atp.api_server import api_workspace
+from atp.server import workspace
 
 
 def main():
     if len(sys.argv) == 1:
         sys.argv.append('--help')
     parser = argparse.ArgumentParser(description='X ATP CLI Client (X 自动化测试平台命令行客户端)')
-    parser.add_argument('-v', '--version', help='输出客户端版本信息', action='version', version='%(prog)s v0.3.1')
+    parser.add_argument('-v', '--version', help='输出客户端版本信息', action='version', version='%(prog)s v0.3.3')
     parser.add_argument('-d', '--demo', help='在当前目录下创建 `x_sweetest_example` 项目',
                         action='store_true')
     parser.add_argument('-r', '--run', dest='atp_server_url',
-                        help='运行 X-ATP 自动测试执行端服务 (E.g x-atp-cli -r http://127.0.0.1 -api -n 执行端001)',
+                        help='运行 X-ATP 自动测试执行端服务 (E.g x-atp-cli -r http://127.0.0.1 -t api -n 执行端001)',
                         action='store')
-    parser.add_argument('-api', '--api', help='运行 API 测试执行端 (used with parameter -r)',
-                        action='store_true', default=False)
-    parser.add_argument('-n', '--name', dest='workspace_name', help='执行端工作区的标识名称 (used with parameter -r)',
+    parser.add_argument('-t', '--type', dest='test_type', help='测试执行端类型 api|web (与 -r 配合使用)',
+                        action='store')
+    parser.add_argument('-n', '--name', dest='workspace_name', help='执行端工作区的标识名称 (与 -r 配合使用)',
                         action='store', default='')
     args = parser.parse_args()
     if args.demo:
@@ -38,12 +38,12 @@ def main():
                         re.IGNORECASE):
             print('[Cli Error]> 这不是有效的URl地址')
             return
-        if args.api:
-            data_json = get_initialization(test_type=0, atp_server_url=args.atp_server_url,
+        if args.test_type.lower() in ('api', 'web'):
+            data_json = get_initialization(test_type=args.test_type.lower(), atp_server_url=args.atp_server_url,
                                            workspace_name=args.workspace_name)
-            api_workspace(sys_name=platform.system(), data=data_json['data'])
+            workspace(sys_name=platform.system(), data=data_json['data'])
         else:
-            print('[Cli Error]> 缺少 -api|-android|-ios|-web 参数')
+            print('[Cli Error]> 缺少 -t api|web 参数')
 
 
 def extract(z_file, path):
@@ -65,11 +65,10 @@ def get_initialization(test_type, atp_server_url, workspace_name):
     if workspace_name == '':
         # 根据当前网卡和时间组成随机数
         workspace_name = uuid.uuid4().hex
-    # api、android、ios、web执行端的通用参数
-    up_data = {'name': workspace_name, 'execution_type': test_type}
-    # api执行端的特殊参数
-    if test_type == 0:
-        up_data['information'] = json.dumps({'system': platform.system()})
+    # api、web执行端的向平台注册的通用参数
+    type_data = {'api': 0, 'web': 3}
+    up_data = {'name': workspace_name, 'execution_type': type_data[test_type]}
+    up_data['information'] = json.dumps({'system': platform.system()})
     # 向ATP平台端发送初始化执行端请求
     requests_data = requests.post(initialization_api_url, data=up_data)
     requests_json = requests_data.json()
@@ -80,6 +79,8 @@ def get_initialization(test_type, atp_server_url, workspace_name):
         sys.exit()
     # 附带上经过上面处理的ATP平台URl
     requests_json['data']['platform_url'] = atp_server_url
+    # 加上测试类型
+    requests_json['data']['test_type'] = test_type
     return requests_json
 
 
