@@ -61,7 +61,8 @@ def options(step):
 
 def request(kw, step):
     element = step['element']
-    url = e.get(element)[1]
+    # 获取 Elements 中的 url，兼容 `{x}` 中的参数为非 str 类型的情况
+    url = str(e.get(element)[1])
     if url.startswith('/'):
         url = url[1:]
 
@@ -99,9 +100,12 @@ def request(kw, step):
     expected['status_code'] = expected.get('status_code', None)
     expected['text'] = expected.get('text', None)
     json_str = expected.get('json', '{}')
+    # 确保第一维数组的下标是存在的
     if json_str[0] == '[' and json_str[1] != ']':
+        # 取出第一维数组的下标
         index = json_str.split(']')[0][1:]
         expected['json'] = json2dict(json_str[len(index) + 2:])
+        # 在预期结果数据中，加入预期的第一维数组的下标
         expected['json_index'] = int(index)
     else:
         expected['json'] = json2dict(expected.get('json', '{}'))
@@ -122,6 +126,9 @@ def request(kw, step):
         if http.headers_get:
             http.r.headers.update(eval(http.headers_get))
 
+    # 变更 user-agent 标识符，便于被测试服务端提取访问记录
+    http.r.headers.update({'user-agent': 'AutoTest'})
+
     logger.info('URL: %s' % http.baseurl + url)
 
     # 处理 before_send
@@ -145,13 +152,18 @@ def request(kw, step):
             logger.info(f'PARAMS: {_data["params"]}')
 
     elif kw == 'post':
+        # 如果 `测试数据` 字段中包含 'form' 的json数据
         if 'form' in data:
+            # 将 'form' json数据转为字典数据
             form_dict = json2dict(data['form'])
             try:
                 if len(form_dict) == 1:
                     for form_k, form_v in form_dict.items():
+                        # 取出待上传的文件名称
                         form_name = form_k.split("/")[-1]
+                        # 使用 MultipartEncoder 模块对上传的文件进行解析
                         form_data = MultipartEncoder(fields={'file': (form_name, open(form_k, 'rb'), form_v)})
+                        # 在请求头里添加上传文件类型
                         form_headers = {'Content-Type': form_data.content_type}
                         http.r.headers.update(form_headers)
                         r = getattr(http.r, kw)(http.baseurl + url, data=form_data, timeout=timeout)
@@ -163,13 +175,16 @@ def request(kw, step):
         logger.info(f'BODY: {r.request.body}')
 
     elif kw in ('put', 'patch'):
+        # 如果 `测试数据` 字段中包含 'binary' 的json数据
         if 'binary' in data:
             binary_dict = json2dict(data['binary'])
             try:
                 if len(binary_dict) == 1:
                     for binary_k, binary_v in binary_dict.items():
+                        # 在请求头里添加上传二进制数据的类型
                         binary_headers = {'Content-Type': binary_v}
                         http.r.headers.update(binary_headers)
+                        # 读取待上传的文件的二进制数据，并传递到待发送的http请求中
                         with open(binary_k, 'rb') as binary_f:
                             r = getattr(http.r, kw)(http.baseurl + url, data=binary_f, timeout=timeout)
             except:
@@ -248,7 +263,9 @@ def request(kw, step):
             logger.info('cookies var: %s' % (repr(result['var'])))
 
     if expected['json']:
+        # 如果预期结果数据中存在第一维数组下标
         if 'json_index' in expected:
+            # 取指定下标的第二维字典数据，并传递给 `injson` 模块处理
             result = check(expected['json'], response['json'][expected['json_index']])
         else:
             result = check(expected['json'], response['json'])
@@ -278,9 +295,13 @@ def request(kw, step):
             logger.info('%s: %s' % (k, repr(g.var[k])))
         elif k == 'json':
             sub_str = output.get('json', '{}')
+            # 如果准备传递给 `injson` 模块处理的字符串中，第一个字符串等于 `[` 号
             if sub_str[0] == '[':
+                # 取出 `[x]` 中的值，即第一维数组的下标
                 index = sub_str.split(']')[0][1:]
+                # 消除前面取第一维数组行为的影响，还原源处理字符串
                 sub = json2dict(sub_str[len(index) + 2:])
+                # 取指定下标的第二维，即字典数据
                 result = check(sub, response['json'][int(index)])
             else:
                 sub = json2dict(output.get('json', '{}'))
